@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2008-2012  Luis Falcon
+#    Copyright (C) 2008-2013  Luis Falcon
 #    Copyright (C) 2012-2012  Sebastián Marró
 
 #    This program is free software: you can redistribute it and/or modify
@@ -184,94 +184,6 @@ def LoadBetzFamilyInfo():
     newborn.sex = 'm'
     newborn.save()
 
-def LoadRandomPatients():
-    Party = Model.get('party.party')
-    Patient = Model.get('gnuhealth.patient')
-    Physician = Model.get('gnuhealth.physician')
-    MedicalSpecialty = Model.get('gnuhealth.specialty')
-    PatientEvaluation = Model.get('gnuhealth.patient.evaluation')
-    Pathology = Model.get('gnuhealth.pathology')
-
-    TODAY = dt.date.today()
-    PATIENT_COUNT = 500
-    PHYSICIAN_COUNT = 10
-    SPECIALTY_COUNT = 59
-    PATHOLOGY_COUNT = 14181
-    for i in range(1, PATIENT_COUNT):
-        party = Party()
-        party.name = 'Name'
-        party.ref = str(i+55000000)
-        party.is_patient = True
-        party.is_person = True
-        party.save()
-
-        patient = Patient()
-        patient.name = party
-        patient.sex = random.choice(['m', 'f'])
-        patient.dob = RandomDate(datetime.strptime('1/1/1925', '%m/%d/%Y'), 
-            datetime.strptime('1/1/2012', '%m/%d/%Y'))
-        patient.save()
-
-        if patient.sex == 'm':
-            party.name = linecache.getline('boy_names', 
-                random.randint(1, 156)).rstrip()
-            party.lastname = linecache.getline('boy_names', 
-                random.randint(1, 156)).rstrip()
-        if patient.sex == 'f':
-            party.name = linecache.getline('girl_names', 
-                random.randint(1, 102)).rstrip()
-            party.lastname = linecache.getline('girl_names', 
-                random.randint(1, 102)).rstrip()
-        party.save()
-
-    for i in range(1, PHYSICIAN_COUNT):
-        party = Party()
-        party.name = 'Name'
-        party.is_doctor = True
-        party.is_person = True
-        party.save()
-
-        physician = Physician()
-        physician.name = party
-        physician.specialty, = MedicalSpecialty.find([
-            ('id', '=', random.randint(1, SPECIALTY_COUNT))
-        ])
-        physician.code = str(i+700000)
-        physician.save()
-
-        if patient.sex == 'm':
-            party.name = linecache.getline('boy_names', 
-                random.randint(1, 156)).rstrip()
-            party.lastname = linecache.getline('boy_names', 
-                random.randint(1, 156)).rstrip()
-        if patient.sex == 'f':
-            party.name = linecache.getline('girl_names', 
-                random.randint(1, 102)).rstrip()
-            party.lastname = linecache.getline('girl_names', 
-                random.randint(1, 102)).rstrip()
-        party.save()
-
-    for patient in Patient.find():
-        for year in range(TODAY.year-5,TODAY.year):
-            evaluation = PatientEvaluation()
-            evaluation.patient = patient
-            evaluation.evaluation_start = RandomDate(
-                datetime.strptime('1/1/'+str(year), '%m/%d/%Y'), 
-                datetime.strptime('12/31/'+str(year), '%m/%d/%Y'))
-            evaluation.evaluation_endtime = evaluation.evaluation_start + \
-                timedelta(minutes=30)
-            evaluation.diagnosis, = Pathology.find([
-                ('id', '=', random.randint(1, PATHOLOGY_COUNT))
-            ])
-            evaluation.doctor, = Physician.find([
-                ('id', '=', random.randint(1, PHYSICIAN_COUNT))
-            ])
-            evaluation.specialty, = MedicalSpecialty.find([
-                ('id', '=', random.randint(1, SPECIALTY_COUNT))
-            ])
-            evaluation.save()
-
 if __name__ == '__main__':
     InitDatabase()
     LoadBetzFamilyInfo()
-    LoadRandomPatients()
