@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,6 +19,26 @@
 #
 ##############################################################################
 
-from health_lab import *
+from trytond.pool import Pool
+from .health_lab import *
 from report import *
 from wizard import *
+
+
+def register():
+    Pool.register(
+        GnuHealthSequences,
+        PatientData,
+        TestType,
+        Lab,
+        GnuHealthLabTestUnits,
+        GnuHealthTestCritearea,
+        GnuHealthPatientLabTest,
+        CreateLabTestOrderInit,
+        module='health_lab', type_='model')
+    Pool.register(
+        CreateLabTestOrder,
+        module='health_lab', type_='wizard')
+    Pool.register(
+        LabTestReport,
+        module='health_lab', type_='report')
