@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,44 +19,43 @@
 #
 ##############################################################################
 from trytond.model import ModelView
-from trytond.wizard import Wizard, StateTransition, StateView, StateTransition, \
-    Button
+from trytond.wizard import Wizard, StateTransition, StateView, Button
 from trytond.transaction import Transaction
-
 from trytond.pool import Pool
 
+
+__all__ = ['CreateLabTestOrderInit', 'CreateLabTestOrder']
+
+
 class CreateLabTestOrderInit(ModelView):
     'Create Test Report Init'
-    _name = 'gnuhealth.lab.test.create.init'
-    _description = __doc__
-
-CreateLabTestOrderInit()
+    __name__ = 'gnuhealth.lab.test.create.init'
 
 
 class CreateLabTestOrder(Wizard):
     'Create Lab Test Report'
-    _name = 'gnuhealth.lab.test.create'
+    __name__ = 'gnuhealth.lab.test.create'
 
     start = StateView('gnuhealth.lab.test.create.init',
         'health_lab.view_lab_make_test', [
             Button('Cancel', 'end', 'tryton-cancel'),
             Button('Create Test Order', 'create_lab_test', 'tryton-ok', True),
             ])
-    
+
     create_lab_test = StateTransition()
 
 
-    def transition_create_lab_test(self, session):
-        test_request_obj = Pool().get('gnuhealth.patient.lab.test')
-        lab_obj = Pool().get('gnuhealth.lab')
+    def transition_create_lab_test(self):
+        TestRequest = Pool().get('gnuhealth.patient.lab.test')
+        Lab = Pool().get('gnuhealth.lab')
 
         test_report_data = {}
         test_cases = []
-        
-        test_obj = test_request_obj.browse(Transaction().context.get('active_ids'))
-        
-        for lab_test_order in test_obj:
-                  
+
+        tests = TestRequest.browse(Transaction().context.get('active_ids'))
+
+        for lab_test_order in tests:
+
             if lab_test_order.state == 'ordered':
                 raise Exception('The Lab test order is already created.')
 
@@ -70,15 +69,13 @@ class CreateLabTestOrder(Wizard):
                         'name': critearea.name,
                         'sequence': critearea.sequence,
                         'lower_limit': critearea.lower_limit,
-                        'upper_limit': critearea.upper_limit,                    
+                        'upper_limit': critearea.upper_limit,
                         'normal_range': critearea.normal_range,
-                        'units': critearea.units.id,
+                        'units': critearea.units and critearea.units.id,
                     }))
             test_report_data['critearea'] = test_cases
-            lab_id = lab_obj.create(test_report_data)
-            test_request_obj.write(lab_test_order.id, {'state': 'ordered'})
-                       
+            Lab.create(test_report_data)
+            TestRequest.write([lab_test_order], {'state': 'ordered'})
+
         return 'end'
-        
 
-CreateLabTestOrder()
