@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #    Copyright (C) 2011  Adrián Bernardi, Mario Puntin (health_invoice)
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -24,24 +24,22 @@ from trytond.pyson import Eval, Equal
 from trytond.pool import Pool
 
 
+__all__ = ['GnuHealthSequences', 'HealthService', 'HealthServiceLine']
+
+
 class GnuHealthSequences(ModelSingleton, ModelSQL, ModelView):
     "Standard Sequences for GNU Health"
-
-    _description = __doc__
-    _name = "gnuhealth.sequences"
+    __name__ = "gnuhealth.sequences"
 
     health_service_sequence = fields.Property(fields.Many2One('ir.sequence',
         'Health Service Sequence', domain=[
             ('code', '=', 'gnuhealth.health_service')
         ], required=True))
 
-GnuHealthSequences()
-
 
 class HealthService(ModelSQL, ModelView):
     'Health Service'
-    _name = 'gnuhealth.health_service'
-    _description = __doc__
+    __name__ = 'gnuhealth.health_service'
 
     name = fields.Char('ID', readonly=True)
     desc = fields.Char('Description', required=True)
@@ -49,65 +47,60 @@ class HealthService(ModelSQL, ModelView):
     service_date = fields.Date('Date')
     service_line = fields.One2Many('gnuhealth.health_service.line',
         'name', 'Service Line', help="Service Line")
-
     state = fields.Selection([
         ('draft', 'Draft'),
         ('invoiced', 'Invoiced'),
         ], 'State', readonly=True)
 
-    def default_state(self):
-        return 'draft'
-
-    def button_set_to_draft(self, ids):
-        self.write(ids, {'state': 'draft'})
-        return True
-
-    def __init__(self):
-        super(HealthService, self).__init__()
-        self._sql_constraints += [
+    @classmethod
+    def __setup__(cls):
+        super(HealthService, cls).__setup__()
+        cls._sql_constraints += [
             ('name_uniq', 'UNIQUE(name)', 'The Service ID must be unique')]
-
-        self._rpc.update({'button_set_to_draft': True})
-
-        self._buttons.update({
+        cls._buttons.update({
             'button_set_to_draft': {'invisible': Equal(Eval('state'),
                 'draft')}
             })
 
-    def create(self, values):
-        sequence_obj = Pool().get('ir.sequence')
-        config_obj = Pool().get('gnuhealth.sequences')
+    @staticmethod
+    def default_state():
+        return 'draft'
+
+    @classmethod
+    @ModelView.button
+    def button_set_to_draft(cls, services):
+        cls.write(services, {'state': 'draft'})
+
+    @classmethod
+    def create(cls, values):
+        Sequence = Pool().get('ir.sequence')
+        Config = Pool().get('gnuhealth.sequences')
 
         values = values.copy()
         if not values.get('name'):
-            config = config_obj.browse(1)
-            values['name'] = sequence_obj.get_id(
-            config.health_service_sequence.id)
-
-        return super(HealthService, self).create(values)
-
-HealthService()
+            config = Config(1)
+            values['name'] = Sequence.get_id(
+                config.health_service_sequence.id)
+        return super(HealthService, cls).create(values)
 
 
 class HealthServiceLine(ModelSQL, ModelView):
     'Health Service'
-    _name = 'gnuhealth.health_service.line'
-    _description = __doc__
+    __name__ = 'gnuhealth.health_service.line'
 
-    name = fields.Many2One('gnuhealth.health_service', 'Service', readonly=True)
+    name = fields.Many2One('gnuhealth.health_service', 'Service',
+        readonly=True)
     desc = fields.Char('Description', required=True)
     appointment = fields.Many2One('gnuhealth.appointment', 'Appointment',
-        help='Enter or select the date / ID of the appointment related to'\
+        help='Enter or select the date / ID of the appointment related to'
         ' this evaluation')
-
     to_invoice = fields.Boolean('Invoice')
     product = fields.Many2One('product.product', 'Product', required=True)
     qty = fields.Integer('Qty')
     from_date = fields.Date('From')
     to_date = fields.Date('To')
 
-    def default_qty(self):
+    @staticmethod
+    def default_qty():
         return 1
 
-HealthServiceLine()
-
