@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,17 +21,19 @@
 from trytond.model import ModelView, ModelSQL, fields
 
 
+__all__ = ['Surgery', 'MedicalOperation', 'MedicalPatient']
+
+
 class Surgery(ModelSQL, ModelView):
     'Surgery Functionality'
-    _name = 'gnuhealth.surgery'
-    _description = __doc__
+    __name__ = 'gnuhealth.surgery'
 
     patient = fields.Many2One('gnuhealth.patient', 'Patient ID')
     admission = fields.Many2One('gnuhealth.appointment', 'Admission')
     operating_room = fields.Many2One('gnuhealth.hospital.or', 'Operating Room')
     code = fields.Char('Code', required=True, help="Health Center Unique code")
     procedures = fields.One2Many('gnuhealth.operation', 'name', 'Procedures',
-        help="List of the procedures in the surgery. Please enter the first " \
+        help="List of the procedures in the surgery. Please enter the first "
         "one as the main procedure")
     pathology = fields.Many2One('gnuhealth.pathology', 'Base condition',
         help="Base Condition / Reason")
@@ -47,20 +49,22 @@ class Surgery(ModelSQL, ModelView):
     date = fields.DateTime('Date')
     age = fields.Char('Patient age',
         help="Patient age at the moment of the surgery. Can be estimative")
-    description = fields.Char('Description', required = True)
+    description = fields.Char('Description', required=True)
     preop_mallampati = fields.Selection([
-        ('Class 1', 'Class 1: Full visibility of tonsils, uvula and soft palate'),
-        ('Class 2', 'Class 2: Visibility of hard and soft palate, ' \
+        ('Class 1', 'Class 1: Full visibility of tonsils, uvula and soft '
+                    'palate'),
+        ('Class 2', 'Class 2: Visibility of hard and soft palate, '
                     'upper portion of tonsils and uvula'),
-        ('Class 3', 'Class 3: Soft and hard palate and base of the uvula are visible'),
+        ('Class 3', 'Class 3: Soft and hard palate and base of the uvula are '
+                    'visible'),
         ('Class 4', 'Class 4: Only Hard Palate visible'),
         ], 'Mallampati Score', sort=False)
     preop_bleeding_risk = fields.Boolean('Risk of Massive bleeding',
-        help="Check this box if patient has a risk of loosing more than 500 " \
-        "ml in adults of over 7ml/kg in infants. If so, make sure that " \
+        help="Check this box if patient has a risk of loosing more than 500 "
+        "ml in adults of over 7ml/kg in infants. If so, make sure that "
         "intravenous access and fluids are available")
     preop_oximeter = fields.Boolean('Pulse Oximeter in place',
-        help="Check this box when verified the pulse oximeter is in place " \
+        help="Check this box when verified the pulse oximeter is in place "
         "and functioning")
     preop_site_marking = fields.Boolean('Surgical Site Marking',
         help="The surgeon has marked the surgical incision")
@@ -70,13 +74,10 @@ class Surgery(ModelSQL, ModelView):
         help="Nursing team has confirmed sterility of the devices and room")
     extra_info = fields.Text('Extra Info')
 
-Surgery()
-
 
 class MedicalOperation(ModelSQL, ModelView):
     'Operation - Surgical Procedures'
-    _name = 'gnuhealth.operation'
-    _description = __doc__
+    __name__ = 'gnuhealth.operation'
 
     name = fields.Many2One('gnuhealth.surgery', 'Surgery')
     procedure = fields.Many2One('gnuhealth.procedure', 'Code', required=True,
@@ -84,15 +85,10 @@ class MedicalOperation(ModelSQL, ModelView):
         help="Procedure Code, for example ICD-10-PCS Code 7-character string")
     notes = fields.Text('Notes')
 
-MedicalOperation()
-
 
 class MedicalPatient(ModelSQL, ModelView):
     'Add to the Medical patient_data class (medical.patient) the surgery ' \
     'field.'
-    _name = 'gnuhealth.patient'
-    _description = __doc__
+    __name__ = 'gnuhealth.patient'
 
     surgery = fields.One2Many('gnuhealth.surgery', 'patient', 'Surgeries')
-
-MedicalPatient()
